package Standup::Role::Project;
use Object::Pad ':experimental';
use Path::Tiny;
use Time::Seconds;

role Project {

  field $project_name :param :reader;

  method get_todo_tasks_from_yesterday {

    # Slurp the yesterday's template file
    my $yesterday = $self->date - Time::Seconds::ONE_DAY;
    my $formated_date = $self->build_path($yesterday->ymd('/'));
    #::p $yesterday;
    #::p $formated_date;
    # Keep all line between - todo and - blocking

  }

  method get_yesterday_file_path {}

}
