package Standup::Role::Date;
use Object::Pad ':experimental';
use Time::Piece;

role Date {
  # For some reason, if we use localtime directly it doesn´t use Time::Piece:localtime one
  field $date :accessor :param { Time::Piece::localtime };
}
