use 5.28.0;

use Object::Pad;

use Getopt::Long qw(GetOptions);

use lib 'lib';
use Standup::Diary;

my $data_dir = 'data';
my $project_name = 'Diary';

GetOptions ("data-dir:s" => \$data_dir,
            "project-name:s"   => \$project_name)
or die("Error in command line arguments\n");

my $diary = Standup::Diary->new( data_dir => $data_dir, project_name => $project_name );

$diary->write;

1;
